@@ -7,8 +7,7 @@
 /*
  * Return an allocated memory area.
  */
-void *
-xmalloc(size_t size)
+void *xmalloc(size_t size)
 {
     void *ptr;
 
