@@ -7,8 +7,7 @@
 /*
  * Resize an allocated memory area.
  */
-void *
-xrealloc(void *ptr, size_t size)
+void *xrealloc(void *ptr, size_t size)
 {
     void *newptr;
 
