@@ -5,8 +5,7 @@
 /*
  * Duplicate a string.
  */
-char *
-xstrdup(const char *s)
+char *xstrdup(const char *s)
 {
     return strcpy(xmalloc(strlen(s) + 1), s);
 }
